quantizationtools.TerminalQEvent
================================

.. abjad-lineage:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent

.. autoclass:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent.TerminalQEvent.__setstate__
   :noindex:
